==> library1.4.1.tar.bz2: library/zhanr/editform.php <==
<?php
///////////////////////////////////////////////////
//Карпухин Павел
//2010 (C)
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['zhanr-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
$button = $TEXT['btn_save'];
$action = "edit.php";

  if(strlen($_GET['zhanr_id'])>5) {puterror($result2['skin'],$TEXT['error-zhanr6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['zhanr_id'] = rep($_GET['zhanr_id']);
  
  $old_zhanr_id = $_GET['zhanr_id'];

  $query10 = "SELECT * FROM `tbl_zhanr` WHERE `zhanr_id`='".$_GET['zhanr_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl14']); require_once "../utils/bottom_adm.php"; exit();}
      $result_zhanr = mysqli_fetch_array($result10);
         $zhanr = $result_zhanr['zhanr'];
?>
<form enctype='multipart/form-data' action=<?php echo $action; ?> method=post>
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size=30 maxlength=127 class="input" type=text name=zhanr value='<?php echo $zhanr; ?>'></td></tr>
<tr><td></td><td><input class="button2" type=submit value='<?php echo $button; ?>'></td></tr>
<input type=hidden name=zhanr_id value='<?php echo $old_zhanr_id; ?>'>
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>

==> library1.19.1.tar.bz2: library/zhanr/editform.php <==
<?php
///////////////////////////////////////////////////
//Карпухин Павел
//2010 (C)
///////////////////////////////////////////////////
require_once "../utils/chlang.php";

$title = $TEXT['zhanr-title'];

require_once "../config_a.php";
require_once "../utils/functions.php";
require_once "../utils/top_adm.php";

if($result2['administrator'] == 0) {puterror($result2['skin'],$TEXT['error-loginform2']); require_once "../utils/bottom_adm.php"; exit();}
$button = $TEXT['btn_save'];
$action = "edit.php";

  if(strlen($_GET['zhanr_id'])>5) {puterror($result2['skin'],$TEXT['error-zhanr6']); require_once "../utils/bottom_adm.php"; exit();}
  $_GET['zhanr_id'] = rep($_GET['zhanr_id']);
  
  $old_zhanr_id = $_GET['zhanr_id'];

  $query10 = "SELECT * FROM `tbl_zhanr` WHERE `zhanr_id`='".$_GET['zhanr_id']."' ";
  $result10 = mysqli_query($dbcnx,$query10);
  if(!$result10) {puterror($result2['skin'],$TEXT['error-tbl14']); require_once "../utils/bottom_adm.php"; exit();}
      $result_zhanr = mysqli_fetch_array($result10);
         $zhanr = rep_back($result_zhanr['zhanr']);
?>
<form enctype="multipart/form-data" action="<?php echo $action; ?>" method="post">
<table align="center">
<tr><td class="bold_it"><?php echo $TEXT['global-edit']; ?></td><td class="bold_it"><input size="30" maxlength="127" type="text" name="zhanr" value="<?php echo $zhanr; ?>" /></td></tr>
<tr><td></td><td><input class="button2" type="submit" value="<?php echo $button; ?>" /></td></tr>
<input type="hidden" name="zhanr_id" value="<?php echo $old_zhanr_id; ?>" />
</table>
</form>
<?php
require_once "../utils/bottom_adm.php";
?>
